int func4(void) {
    return 4;
}
